@@ -1,7 +1,7 @@
-__version__ = '0.1.7'
+__version__ = '0.1.9'
 
 import exgrads.grad1
-from exgrads.trH import trH
+import exgrads.trH
 
 __all__ = [
 	'__version__',
