@@ -14,15 +14,16 @@ def vectorize(model, x, y):
 	model.zero_grad()
 	loss.backward()
 
+	hooks.compute_grad1(model)
+
 	vectors = []
 	for param in model.parameters():
 		if not hasattr(param, 'grad1'): continue
 		grad1 = param.grad1.detach()
 		grad1 = grad1.flatten(1,-1)
 		vectors.append(grad1)
-		del param.grad1
 	vectors = torch.cat(vectors,dim=1)
-
+	
 	hooks.deregister(model)
 	return vectors
 
@@ -43,12 +44,9 @@ def normL2(model, x, y):
 	norms = torch.zeros(x.shape[0])
 	norms = norms.to(x.device)
 
-	for param in model.parameters():
-		if not hasattr(param, 'grad1'): continue
-		grad1 = param.grad1.detach()
+	for grad1 in hooks.generate_grad1(model):
 		grad1 = grad1.flatten(1,-1)
 		norms += grad1.pow(2).sum(dim=1)
-		del param.grad1
 	norms = norms.pow(0.5)
 	
 	hooks.deregister(model)
