@@ -4,7 +4,7 @@
 # -------------------------------------------------------
 import torch
 import exgrads.hooks as hooks
-def trH(model, x):
+def withNNH(model, x):
 	model.eval()
 	hooks.register(model)
 	
@@ -19,12 +19,11 @@ def trH(model, x):
 	
 	loss.backward(retain_graph=True)
 	model.zero_grad()
-	for param in model.parameters():
-		grad1 = param.grad1**2 						# := (b,*)
+	for grad1 in hooks.generate_grad1(model):
+		grad1 = grad1**2 							# := (b,*)
 		grad1 = grad1.flatten(1,-1) 				# -> (b,prod(*))
 		grad1 = torch.sum(grad1,dim=1) 				# -> (b,)
 		results -= grad1.detach()
-		del param.grad1
 
 	# for diag(p) part
 	prob	= torch.softmax(logit,dim=1)				# -> (b,K)
@@ -33,15 +32,13 @@ def trH(model, x):
 	for k, logit_k in enumerate(logit):
 		logit_k.backward(retain_graph=True)
 		model.zero_grad()
-		for param in model.parameters():
-			grad1 = param.grad1**2					# := (b,*)
+		for grad1 in hooks.generate_grad1(model):
 			grad1 = grad1.flatten(1,-1)				# -> (b,prod(*))
 			grad1 = prob[:,k] * grad1				# -> (b,prod(*))
 			grad1 = grad1.flatten(1,-1)				# -> (b)
 			grad1 = torch.sum(grad1,dim=1)			# -> (b)
 			results += grad1.detach()
-			del param.grad1
-	
+		
 	hooks.deregister(model)
 	return results
 
